@@ -25,7 +25,9 @@
 
 #include "abstractbrowserplugin.h"
 
+#include <QHash>
 #include <QString>
+#include <QTimer>
 #include <QUrl>
 
 class QDBusObjectPath;
@@ -39,6 +41,8 @@ class MPrisPlugin : public AbstractBrowserPlugin
     Q_PROPERTY(QString Identity READ identity)
     Q_PROPERTY(QString DesktopEntry READ desktopEntry)
     Q_PROPERTY(bool CanRaise READ canRaise)
+    Q_PROPERTY(bool Fullscreen READ fullscreen WRITE setFullscreen NOTIFY fullscreenChanged)
+    Q_PROPERTY(bool CanSetFullscreen READ canSetFullscreen NOTIFY canSetFullscreenChanged)
 
     // Player
     Q_PROPERTY(bool CanGoNext READ canGoNext)
@@ -61,6 +65,7 @@ public:
 
     bool onUnload() override;
 
+    using AbstractBrowserPlugin::handleData;
     void handleData(const QString &event, const QJsonObject &data) override;
 
     // mpris properties ____________
@@ -70,6 +75,10 @@ public:
     QString desktopEntry() const;
     bool canRaise() const;
 
+    bool fullscreen() const;
+    void setFullscreen(bool fullscreen);
+    bool canSetFullscreen() const;
+
     // Player
     bool canGoNext() const;
     bool canGoPrevious() const;
@@ -114,6 +123,8 @@ public:
     void OpenUri(const QString &uri);
 
 Q_SIGNALS:
+    void fullscreenChanged();
+    void canSetFullscreenChanged();
     void canControlChanged();
     void playbackStatusChanged();
     void canSeekChanged();
@@ -124,6 +135,7 @@ Q_SIGNALS:
 
 private:
     void emitPropertyChange(const QDBusAbstractAdaptor *interface, const char *propertyName);
+    void sendPropertyChanges();
 
     bool registerService();
     bool unregisterService();
@@ -139,8 +151,15 @@ private:
     QDBusAbstractAdaptor *m_root;
     QDBusAbstractAdaptor *m_player;
 
+    QTimer m_propertyChangeSignalTimer;
+    // interface - <property name, value>
+    QHash<QString, QVariantMap> m_pendingPropertyChanges;
+
     QString m_serviceName;
 
+    bool m_fullscreen = false;
+    bool m_canSetFullscreen = false;
+
     QString m_playbackStatus;
     QString m_loopStatus;
     QHash<QString, bool> m_possibleLoopStatus;
@@ -149,6 +168,8 @@ private:
     bool m_canGoPrevious = false;
 
     QString m_pageTitle;
+    QString m_tabTitle;
+
     QUrl m_url;
     QUrl m_mediaSrc;
 
